@@ -53,6 +53,8 @@ addReact <- function(model,
     if (!is(model, "modelorg")) {
         stop("needs an object of class modelorg!")
     }
+	
+	stopifnot(checkVersion(model))
 
     if (length(met) != length(Scoef)) {
         stop("arguments 'met' and 'Scoef' must have the same length")
@@ -137,6 +139,11 @@ addReact <- function(model,
         newsubSys       <- subSys(model)
 
         newS            <- S(model)
+        
+        newMetAttr <- met_attr(model)
+        newReactAttr <- react_attr(model)
+        newCompAttr <- comp_attr(model)
+        newModAttr <- mod_attr(model)
 
     
         if (isTRUE(addRow)) {
@@ -179,6 +186,11 @@ addReact <- function(model,
                                       nrow = nNewRows,
                                       ncol = react_num(model))
             newS <- Matrix::rBind(newS, newRows)
+            
+            # new met attrs
+            if(ncol(newMetAttr) > 0){
+            	newMetAttr[nrow(newMetAttr)+1:nNewRows, ] <- NA
+            }
         }
     
         if (isTRUE(addCol)) {                        # we add at most one column
@@ -209,6 +221,12 @@ addReact <- function(model,
             # new column in stoichiometric matrix
             newS <- cBind(newS, rep(0, nrow(newS)))
             
+            # new react Attr
+            # only one new row, /bc we can only add one reaction a time.
+            if(ncol(newReactAttr) > 0){
+            	newReactAttr[nrow(newReactAttr)+1, ] <- NA
+            }
+            
             # subsystems
             if (any(is.na(subSystem))) {
             	ss <- subSys(model)
@@ -290,13 +308,14 @@ addReact <- function(model,
                 # genes per reaction
                 newgenes <- append(genes(model), list(gene_rule$gene))
                 newrule  <- gene_rule$rule
-
-                for (j in 1 : length(geneInd)) {
-                    pat  <- paste("x(", j, ")", sep = "")
-                    repl <- paste("x[", geneInd[j], "]", sep = "")
-    
-                    newrule <- gsub(pat, repl, newrule, fixed = TRUE)
-                }
+				
+				# not needed for modelorg version 2.0
+#                for (j in 1 : length(geneInd)) {
+#                    pat  <- paste("x(", j, ")", sep = "")
+#                    repl <- paste("x[", geneInd[j], "]", sep = "")
+#    
+#                    newrule <- gsub(pat, repl, newrule, fixed = TRUE)
+#                }
 
                 newgprRules <- append(gprRules(model), newrule)
             }
@@ -317,9 +336,9 @@ addReact <- function(model,
         if (is(model, "modelorg_irrev")) {
             mod_out <- modelorg_irrev(mod_id(model), mod_name(model))
             irrev(mod_out)     <- TRUE
-            matchrev(mod_out)  <- append(matchrev(model), 0)
+            matchrev(mod_out)  <- append(matchrev(model), 0L)
             
-            revReactId <- max(irrev2rev(model))+1
+            revReactId <- as.integer(max(irrev2rev(model))+1)
             irrev2rev(mod_out) <- append(irrev2rev(model), revReactId)
             rev2irrev(mod_out) <- rbind(rev2irrev(model), c(nCols, nCols))
         }
@@ -356,6 +375,12 @@ addReact <- function(model,
         subSys(mod_out)       <- newsubSys
 
         S(mod_out)            <- newS
+        
+        react_attr(mod_out) <- newReactAttr
+        met_attr(mod_out) <- newMetAttr
+        comp_attr(mod_out) <- newCompAttr
+        mod_attr(mod_out) <- newModAttr
+        
 
     }
     else {
